<?php
/**
 * MediaWiki extension wrapper for installation of it-mate.co.uk's spambotsearchtool
 *
 * An extension for blocking users names and IP addresses based on external 
 * blacklist servers. Requires check_spammers_plain.php and related scripts from 
 * http://support.it-mate.co.uk/?mode=Products&act=DL&p=spambotsearchtool
 *
 * @file
 * @ingroup Extensions
 */
 
 
include ("check_spammers_plain.php");
$wgHooks['GetBlockedStatus'][] = 'CheckSpambots::check_edit';
$wgHooks['AbortNewAccount'][] = 'CheckSpambots::check_newuser';
 
$wgExtensionCredits['other'][] = array(
    'name' => 'Check Spambots',
    'version' => '0.1',
    'author' => 'MysteryFCM et al.',
    'description' => 'Spambot Search Tool, blocks known spambots based on external DNS and HTTP blacklists.',
    'descriptionmsg' => '',
    'url' => 'http://www.mediawiki.org/wiki/Extension:Check_Spambots',
);
 
class CheckSpambots {
 
    /**
     * On edit/save: get user's IP/name/e-mail if known
     * then call checkSpambots() from SpambotSearchTool
     *
     * @param $current_user User: current user
     */
    public static function check_edit( $current_user ) 
    {
        wfProfileIn( __METHOD__ );
 
        $ip_to_check = wfGetIP();
        $mail = '';
        $name = '';
 
        if ( $current_user instanceof User ) 
        {
           $name = $current_user->getName();
           $mail = $current_user->getEmail();
        }
 
        if (checkSpambots($mail,$ip_to_check,$name))
        {
           $current_user->mBlockedby = wfMsg( 'proxyblocker' );
           $current_user->mBlockreason = wfMsg( 'proxyblockreason' );      
        }
 
        wfProfileOut( __METHOD__ );
        return true;
    }
 
   /**
    * On registration: Perform the check on new user e-mail/name/IP
    * @param $user User to be checked
    * @return bool
    */
   public static function check_newuser( $current_user ) {
        wfProfileIn( __METHOD__ );
 
        $ip_to_check = wfGetIP();
        $mail = '';
        $name = '';
 
        if ( $current_user instanceof User ) 
        {
           $name = $current_user->getName();
           $mail = $current_user->getEmail();
        }
 
        if (checkSpambots($mail,$ip_to_check,$name))
        {
                global $wgOut;
                $returnTitle = Title::makeTitle( NS_SPECIAL, 'Userlogin' );
                $wgOut->errorPage( 'blacklistedusername', 'blacklistedusernametext' );
                $wgOut->returnToMain( false, $returnTitle->getPrefixedText() );
                wfProfileOut( __METHOD__ );
                return false;
        }
 
        wfProfileOut( __METHOD__ );
        return true;
    }
}